[−][src]Struct crypto::hmac::Hmac
The Hmac struct represents an Hmac function - a Message Authentication Code using a Digest.
Methods
impl<D: Digest> Hmac<D>[src]
impl<D: Digest> Hmac<D>Trait Implementations
impl<D: Digest> Mac for Hmac<D>[src]
impl<D: Digest> Mac for Hmac<D>fn input(&mut self, data: &[u8])[src]
fn input(&mut self, data: &[u8])Process input data. Read more
fn reset(&mut self)[src]
fn reset(&mut self)Reset the Mac state to begin processing another input stream.
fn result(&mut self) -> MacResult[src]
fn result(&mut self) -> MacResultObtain the result of a Mac computation as a MacResult.
fn raw_result(&mut self, output: &mut [u8])[src]
fn raw_result(&mut self, output: &mut [u8])Obtain the result of a Mac computation as [u8]. This method should be used very carefully since incorrect use of the Mac code could result in permitting a timing attack which defeats the security provided by a Mac function. Read more
fn output_bytes(&self) -> usize[src]
fn output_bytes(&self) -> usizeGet the size of the Mac code, in bytes.